@@ -244,7 +244,7 @@ class Move(metaclass=PoolMeta):
         unknown_country = []
         for move in moves:
             move._set_intrastat()
-            if (not move.intrastat_type
+            if (move.intrastat_type
                     and (not move.intrastat_from_country
                         or not move.intrastat_to_country)):
                 unknown_country.append(move)
@@ -418,7 +418,7 @@ class Move(metaclass=PoolMeta):
                 return round(Currency.compute(
                         self.currency,
                         self.unit_price * Decimal(str(self.quantity)),
-                        self.company.intrastat_currency,
+                        self.company.intrastat_currency or self.currency,
                         round=False), ndigits)
 
     def _intrastat_quantity(self, unit):
@@ -571,6 +571,10 @@ class ShipmentIn(ShipmentMixin, metaclass=PoolMeta):
 
     @fields.depends('supplier')
     def on_change_supplier(self):
+        try:
+            super().on_change_supplier()
+        except AttributeError:
+            pass
         if self.supplier:
             address = self.supplier.address_get(type='delivery')
             if address:
@@ -634,6 +638,10 @@ class ShipmentOutReturn(ShipmentMixin, metaclass=PoolMeta):
 
     @fields.depends('customer')
     def on_change_customer(self):
+        try:
+            super().on_change_customer()
+        except AttributeError:
+            pass
         if self.customer:
             address = self.customer.address_get(type='delivery')
             if address:
